@@ -311,6 +311,12 @@ class R3sponse(object):
 			json=None,
 		):
 
+			# check self instance.
+			if isinstance(attributes, ResponseObject):
+				attributes = attributes.dict()
+			if isinstance(json, ResponseObject):
+				json = json.dict()
+
 			# assign attributes.
 			if json != None:
 				if isinstance(json, str):
